var ContactList = Class.create({

    contacts: null,
    selectedIds: null,
    dialog: null,
    control: null,
    targetInput: null,
    contactSelectionListener: null,
    showContactListHandler: null,

    _constructor: function() {
        this.contacts = [];
        this.selectedIds = [];
        this.showContactListHandler = this.showContactList.bind(this);
        this.contactSelectionListener = {
            onSubmit: this._onContactSelected.bind(this),
            onCancel: function(){}
        }
    },

    setControl: function(control) {
        if (this.control != null) {
            Event.unobserve(this.control, "click", this.showContactListHandler);
        }

        this.control = control;
        Event.observe(control, "click", this.showContactListHandler);
        Utils.setStyle(control, "cursor:pointer");
    },

    setTargetInput: function(element) {
        this.targetInput = element;
    },

    setContacts: function(data) {
        this.contacts = [];
        var values = $A(data);

        for (var i = 0, size = values.length; i < size; i=i+2) {
            var name = values[i];
            var email = i + 1 < size ? values[i+1] : "";
            this.contacts.push({id: String(name+email), name: name, email: email});
        }

        Utils.setVisible(this.control, this.contacts.length != 0);
    },

    showContactList: function() {
        if (this.dialog == null) {
            this.dialog = this._createDialog();
            this.dialog.pack();
        }

        this.dialog.setSelectedItems(this._getContactsById(this.selectedIds));
        this.dialog.show(this.contactSelectionListener);
    },

    hideContactList: function() {
        if (this.dialog != null) {
            this.dialog.setVisible(false);
        }
        this.selectedIds = [];
    },

    _onContactSelected: function(dialog, contacts) {
        this.selectedIds = [];
        for (var i = 0; i < contacts.length; ++i) {
            this.selectedIds.push(contacts[i].id);
        }

        if (Object.isElement(this.targetInput)) {
            this.targetInput.value = this._toInputFieldValue(contacts, ContactList.EMAIL_DELIM);
        }
    },

    _createDialog: function() {
        return new ContactListDialog([].concat(this.contacts));
    },

    _getContactsById: function(ids) {
        var result = [];
        for (var i = 0; i < this.contacts.length; ++i) {
            var contact = this.contacts[i];
            for (var j = 0; j < ids.length; ++j) {
                if (contact.id == ids[j]) {
                    result.push(contact);
                    break;
                }
            }
        }

        return result;
    },

    _toInputFieldValue: function(contacts, delimeter) {
        delimeter = delimeter || " ";
        var result = "";
        for (var i = 0, size = contacts.length; i < size; ++i) {
            result += this._formatContact(contacts[i]);
            if (i < size - 1) {
                result += delimeter;
            }
        }

        return result;
    },

    _formatContact: function(contact) {
        return "\"" + contact.name + "\" <" + contact.email + ">";
    }

});

ContactList.EMAIL_DELIM = ", ";