var ContactListDialog = Class.create(ModalDialog, {

    inputs: null,
    inputStateHandler: null,
    contacts: null,

    _constructor: function(contacts) {
        this.inputs = [];
        this.inputStateHandler = this._updateButtons.bind(this);
        this.contacts = contacts;

        this.setTitle(ContactListDialog.TITLE);
        this.setContent(this._createContentPane());
        this.addButton(ModalDialog.BUTTON_OK, ContactListDialog.Buttons.OK, this.onSubmit.bind(this));
        this.addButton(ModalDialog.BUTTON_CANCEL, ContactListDialog.Buttons.CANCEL, this.onCancel.bind(this));
        this.setButtonEnabled(ModalDialog.BUTTON_OK, false);
    },

    setVisible: function(visible) {
        this._super.setVisible.call(this, visible);
        this._updateButtons();
    },

    show: function(listener) {
        this.listener = listener;
        this.setVisible(true);
    },

    onSubmit: function() {
        this.setVisible(false);

        if (this.listener != null) {
            this.listener.onSubmit(this, this.getSelectedItems());
        }
    },

    onCancel: function() {
        this.setVisible(false);

        if (this.listener != null) {
            this.listener.onCancel(this);
        }
    },

    _createContentPane: function() {
        var panel = document.createElement(Tag.DIV);
        for (var i = 0, size = this.contacts.length; i < size; ++i) {
            var contact = this.contacts[i];
            var input = Utils.createInput(Tag.INPUT_TYPE_CHECKBOX, "contact" + i);
            input.id = contact.id;
            input.value = contact.id;
            this.inputs.push(input);

            panel.appendChild(this._createInputPane(input, contact));
            Event.observe(input, "click", this.inputStateHandler);
        }

        return panel;
    },

    _createInputPane: function(input, contact) {
        var panel = document.createElement(Tag.PARAGRAPH);
        var label = document.createElement(Tag.LABEL);
        label.htmlFor = input.id;
        var email = document.createElement(Tag.SPAN);
        email.appendChild(document.createTextNode(" <" + contact.email + ">"));
        Utils.setStyle(email, "color:#777;");

        label.appendChild(document.createTextNode(" \"" + contact.name +"\""));
        label.appendChild(email);

        panel.appendChild(input);
        panel.appendChild(label);

        return panel;
    },

    getSelectedItems: function() {
        var result = [];

        for (var i = 0, s1 = this.inputs.length; i < s1; ++i) {
            var contactId = $F(this.inputs[i]);

            for (var j = 0, s2 = this.contacts.length; j < s2; ++j) {
                var contact = this.contacts[j];
                if (contact.id == contactId) {
                    result.push(contact);
                    break;
                }
            }
        }

        return result;
    },

    setSelectedItems: function(contacts) {
        for (var i = 0; i < this.inputs.length; ++i) {
            var input = this.inputs[i];
            var found = false;
            for (var j = 0; j < contacts.length; ++j) {
                if (input.value == contacts[j].id) {
                    found = true;
                    break;
                }
            }
            input.checked = found;
        }
    },

    _updateButtons: function() {
        var enabled = this.getSelectedItems().length != 0;
        this.setButtonEnabled(ModalDialog.BUTTON_OK, enabled);
    }

});

ContactListDialog.TITLE = "Contact List";
ContactListDialog.Buttons = {OK: 'OK', CANCEL: 'Cancel'};