var TagDocumentDialog = Class.create(ModalDialog, {

    form: null,
    document: null,
    channel: null,
    messageHolder: null,


    _constructor: function(url) {
        this.channel = new IFrameChannel("TagDocumentDataChannel");
        this.channel.setPreventCaching(true);
        this.channel.open(url);
        this.channel.addLoadListener(this.onFormLoaded.bind(this));

        var content = this.getContent();
        this.messageHolder = content.appendChild(document.createElement(Tag.DIV));
        content.appendChild(this.channel.asElement());

        Utils.setStyle(this.messageHolder, {display: "none", textAlign: "center", margin: "2em auto"});
        Utils.setStyle(this.channel.asElement(), {width: 0, height: 0, display: "none"});

        this.setTitle(TagDocumentDialog.TITLE);
        this.addButton(ModalDialog.BUTTON_OK, TagDocumentDialog.Buttons.SAVE, this.onSubmit.bind(this));
        this.addButton(ModalDialog.BUTTON_CANCEL, TagDocumentDialog.Buttons.CANCEL);
    },

    getId: function() {
        return "TagDocumentDialog";
    },

    dispose: function() {
        this.form = null;
        this.channel.close();
        this._super.dispose.call(this);
    },

    setDocument: function(document) {
        this.document = document;
    },

    setVisible: function(visible) {
        if (visible) {
            this.setButtonEnabled(ModalDialog.BUTTON_OK, false);
            this.setMessage(TagDocumentDialog.Messages.LOADING);
            this.form = null;
            this.channel.send({filename: this.document});
        }

        this._super.setVisible.call(this, visible);
    },

    setMessage: function(message) {
        if (message != null) {
            while (this.messageHolder.hasChildNodes()) {
                this.messageHolder.removeChild(this.messageHolder.lastChild);
            }
            this.messageHolder.appendChild(document.createTextNode(message));

            Utils.setStyle(this.channel.asElement(), {display: "none"});
            Utils.setStyle(this.messageHolder, {display: "block"});
            this.pack();
        } else {
            Utils.setStyle(this.channel.asElement(), {width: "100%", height: "100%", display: "block"});
            Utils.setStyle(this.messageHolder, {display: "none"});
            this.setSize(470, 180);
        }
    },

    onSubmit: function() {
        if (this.form != null) {
            this.setButtonEnabled(ModalDialog.BUTTON_OK, false);
            this.form.submit();
        }
    },

    onFormLoaded: function() {
        var forms = this.channel.asDocument().forms;

        if (forms.length != 0) {
            this.form = forms[0];
            Event.observe(this.form, "submit", this.onSubmit.bind(this));
        } else {
            this.form = null;
        }

        this.setButtonEnabled(ModalDialog.BUTTON_OK, true);
        this.setMessage(null);
    }

});

TagDocumentDialog.TITLE = "Manage Tags";
TagDocumentDialog.Buttons = {SAVE: 'Save', CANCEL: 'Cancel'};
TagDocumentDialog.Messages = {LOADING: 'Loading...'};


