function ButtonsBarPane(disabledCssClass, registerKeystroke) {
    this._constructor(disabledCssClass, registerKeystroke);
}(function(){

    ButtonsBarPane.prototype = {

        viewButton: null,
        renameButton: null,
        refreshButton: null,
        newDirectoryButton: null,
        deleteButton: null,
        emailButton: null,
        emailFileEnabled: null,
        manageTagsButton: null,
        disabledCssClass: null,
        registerKeystroke: null,

        _constructor: function(disabledCssClass, registerKeystroke) {
            this.disabledCssClass = disabledCssClass;
            this.registerKeystroke = registerKeystroke;
            this.emailFileEnabled = false;
        },

        registerViewButton: function(button, handler, keystroke) {
            this.viewButton = this._bind(button, handler, keystroke);
        },

        registerRenameButton: function(button, handler, keystroke) {
            this.renameButton = this._bind(button, handler, keystroke);
        },

        registerRefreshButton: function(button, handler, keystroke) {
            this.refreshButton = this._bind(button, handler, keystroke);
        },

        registerNewDirectoryButton: function(button, handler, keystroke) {
            this.newDirectoryButton = this._bind(button, handler, keystroke);
        },

        registerDeleteButton: function(button, handler, keystroke) {
            this.deleteButton = this._bind(button, handler, keystroke);
        },

        registerEmailButton: function(button, handler, keystroke, isEmailFileEnabled) {
            this.emailButton = this._bind(button, handler, keystroke);
            this.emailFileEnabled = isEmailFileEnabled;
        },

        registerManageTagsButton: function(button, handler, keystroke) {
            this.manageTagsButton = this._bind(button, handler, keystroke);
        },

        _bind: function(button, handler, keystroke) {
            button.performAction = function() {
                if (!this.disabled) {
                    handler();
                }
            };

            button.onclick = function() {
                this.performAction();
                return false;
            };

            if (keystroke != null && this.registerKeystroke) {
                button.processKeyEvent = function(ke) {
                    if (!ke.isModifiersDown()) {
                        ke.cancel();
                        this.performAction();
                    }
                };

                KeyboardManager.getInstance().registerHandler(keystroke, button);
            }

            return button;
        },

        update: function() {
            var markedFiles = getMarkedFiles();
            var selectedFile = getSelectedFile();
            var isAnyFileSelected = (markedFiles.length != 0 || selectedFile != null);
            var isSingleFileSelected = (markedFiles.length == 0 && selectedFile != null)
                                       || (markedFiles.length == 1
                                           && (markedFiles[0] == selectedFile || selectedFile == null));

            Utils.setEnabled(this.viewButton, isSingleFileSelected, this.disabledCssClass);
            Utils.setEnabled(this.renameButton, (selectedFile != null), this.disabledCssClass);
            Utils.setEnabled(this.deleteButton, isAnyFileSelected, this.disabledCssClass);
            Utils.setEnabled(this.emailButton, this.emailFileEnabled && isAnyFileSelected, this.disabledCssClass);
            Utils.setEnabled(this.manageTagsButton, isSingleFileSelected, this.disabledCssClass);
        }

    };
})();