var ManageIpAccessPane = Class.create({

    itemBoxes: null,
    selectAllBox: null,
    editButton: null,
    deleteButton: null,

    _constructor: function(itemBoxes, selectAllBox, editButton, deleteButton) {
        this.itemBoxes = itemBoxes;
        this.selectAllBox = selectAllBox;
        this.editButton = editButton;
        this.deleteButton = deleteButton;

        for (var i = 0, size = this.itemBoxes.length; i < size; ++i) {
            Event.observe(this.itemBoxes[i], "click", this._update.bind(this));
        }

        Event.observe(this.selectAllBox, "click", this._handleSelectAll.bind(this));
        Event.observe(this.editButton, "click", this._handleEdit.bindAsEventListener(this));
        Event.observe(this.deleteButton, "click", this._handleDelete.bindAsEventListener(this));

        this._update();
    },

    _handleSelectAll: function() {
        var selected = this.selectAllBox.checked;
        for (var i = 0, size = this.itemBoxes.length; i < size; ++i) {
            this.itemBoxes[i].checked = selected;
        }
        this._update();
    },

    _handleEdit: function(e) {
        if (this._getSelectionCount() != 1) {
            Event.stop(e);
        }
    },

    _handleDelete: function(e) {
        if (this._getSelectionCount() == 0) {
            Event.stop(e);
        } else {
            this._doDeleteLocal.bind(this).delay(100);
        }
    },

    _doDeleteLocal: function() {
        var newBoxes = [];

        for (var i = 0, size = this.itemBoxes.length; i < size; ++i) {
            var candidate = this.itemBoxes[i];
            if (candidate.checked) {
                var row = this._getParentRow(candidate);
                row.parentNode.removeChild(row);
            } else {
                newBoxes.push(candidate);
            }
        }

        this.itemBoxes = newBoxes;
        this._update();
    },

    _getSelectionCount: function() {
        var count = 0;
        for (var i = 0, size = this.itemBoxes.length; i < size; ++i) {
            if (this.itemBoxes[i].checked) {
                ++count;
            }
        }
        return count;
    },

    _getParentRow: function(elem) {
        for (var el = elem.parentNode; el != null; el = el.parentNode) {
            if (Utils.isRow(el)) {
                return el;
            }
        }
        return null;
    },

    _update: function() {
        var selectionCount = this._getSelectionCount();
        var itemCount = this.itemBoxes.length;

        this.selectAllBox.checked = (itemCount == selectionCount && itemCount != 0);
        Utils.setEnabled(this.selectAllBox, itemCount != 0);
        Utils.setEnabled(this.editButton, selectionCount == 1);
        Utils.setEnabled(this.deleteButton, selectionCount != 0 && itemCount > 0);
    }

});