var NewDirectoryDialog = Class.create(ModalDialog, {

    dirField: null,
    dirFieldKeyboardHandler: null,

    _constructor: function() {
        this.dirField = Utils.createTextInput("newDirInputField");
        this.dirFieldKeyboardHandler = this._updateButtons.bind(this);
        Event.observe(this.dirField, "keyup", this.dirFieldKeyboardHandler);

        this.getContent().appendChild(Utils.createLabel(NewDirectoryDialog.Labels.NAME, this.dirField.name));
        this.getContent().appendChild(this.dirField);

        this.addButton(ModalDialog.BUTTON_OK, NewDirectoryDialog.Buttons.OK, this.onSubmit.bind(this));
        this.addButton(ModalDialog.BUTTON_CANCEL, NewDirectoryDialog.Buttons.CANCEL, this.onCancel.bind(this));
        this.setButtonEnabled(ModalDialog.BUTTON_OK, false);
    },

    getId: function() {
        return "NewDirectoryDialog";
    },

    setVisible: function(visible) {
        this._super.setVisible.call(this, visible);

        this._updateButtons();
    },

    getDirectoryName: function() {
        var result = $F(this.dirField);
        return (result != null) ? result : "";
    },

    onSubmit: function() {
        this.setVisible(false);
        var name = this.getDirectoryName();

        if (this._isValidDirName(name)) {
            new Action(Action.NEW_DIRECTORY, getActionForm()).perform(createParameters(name));
        }
    },

    onCancel: function() {
        this.dirField.value = '';
        Event.unobserve(this.dirField, "keyup", this.dirFieldKeyboardHandler);
        this.dirFieldKeyboardHandler = null;

        this.dispose();
    },

    _isValidDirName: function(name) {
        return name != null && name.trim().length > 0;
    },

    _updateButtons: function() {
        var enabled = this._isValidDirName(this.getDirectoryName());
        this.setButtonEnabled(ModalDialog.BUTTON_OK, enabled);
    },

    _requestFocus: function() {
        this._super._requestFocus.call(this, this.dirField);
    }

});

NewDirectoryDialog.Labels = {NAME: 'New directory'};
NewDirectoryDialog.Buttons = {OK: 'OK', CANCEL: 'Cancel'};