function ProgressPresenter(listener, url) {
    this._constructor(listener, url);
}
(function() {

    ProgressPresenter.URL = "";

    var DEFAULT_DECAY = 2;
    var POLLING_TIMEOUT = 1000;

    ProgressPresenter.prototype = {

        url: null,
        view: null,
        commandChannel: null,
        decay: null,
        currentDecay: null,
        lastData: null,
        lastActivityTime: null,
        pollTimer: null,
        pollingTimeout: null,

        _constructor: function(listener, url) {
            this.url = url || ProgressPresenter.URL;
            this.view = new ProgressView(listener);
            this.commandChannel = new ScriptChannel("uploadprogresschannel");
            this.commandChannel.setPreventCaching(true);

            this.lastActivityTime = 0;
            this.pollingTimeout = POLLING_TIMEOUT;
            this.setDecay(DEFAULT_DECAY);
        },

        setDecay: function(decay) {
            this.decay = decay || DEFAULT_DECAY;
            this.currentDecay = this.decay;
        },

        setIndeterminate: function() {
            this.view.setIndeterminate();
        },

        start: function() {
            this.commandChannel.open(this.url);
            this.view.setVisible(true);
            this._scheduleNextPoll();
        },

        finish: function() {
            this._clearTimers();
            this.commandChannel.close();
            this.view.setVisible(false);
        },

        cancel: function() {
            this.finish();
        },

        onUploadPending: function() {
            this.setIndeterminate();
            this._scheduleNextPoll();
        },

        onUploadProgress: function(percent, status, time) {
            this._progress(percent, status, time);

            var data = status + time;
            this.currentDecay = (this.lastData == data) ? this.currentDecay + this.decay : 1;
            this.lastData = data;
            this._scheduleNextPoll(this.currentDecay);
        },

        onCopyProgress: function(percent, status, time) {
            this._progress(percent, status, time);
            this._scheduleNextPoll();
        },

        toString: function() {
            return "ProgressPresenter";
        },

        _progress: function(percent, statusMessage, timeMessage) {
            if (percent != -1) {
                this.view.setProgress(percent);
            }
            this.view.setStatus(statusMessage);
            this.view.setTime(timeMessage);
        },

        _scheduleNextPoll: function(decay) {
            window.clearTimeout(this.pollTimer);
            this.pollTimer = (function() {
                this.commandChannel.send("");
            }.bind(this).delay(this.pollingTimeout * (decay || 1)));
        },

        _clearTimers: function() {
            window.clearTimeout(this.pollTimer);
        }
    };
})();